@@ -17,13 +17,17 @@
    See the COPYING file for a copy of the GNU General Public License.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "theme.h"
 #include "main.h"
 #include "tree.h"
 
 #include <string.h>
 
-#include <openbox/theme.h>
+#include <obrender/theme.h>
 
 #if GTK_CHECK_VERSION(3, 0, 0)
 #include <gdk/gdkx.h>
@@ -38,7 +42,8 @@ GdkPixbuf *preview_theme(const gchar *name, const gchar *titlelayout,
                          RrFont *inactive_window_font,
                          RrFont *menu_title_font,
                          RrFont *menu_item_font,
-                         RrFont *osd_font);
+                         RrFont *osd_active_font,
+                         RrFont *osd_inactive_font);
 
 /* End forwarded */
 
@@ -548,28 +553,53 @@ static GdkPixbuf* preview_window(RrTheme *theme, const gchar *titlelayout,
             switch (*layout) {
             case 'D':
                 a = focus ?
+#ifdef HAVE_OPENBOX_3_5_2
+                    theme->btn_desk->a_focused_unpressed :
+                    theme->btn_desk->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_desk :
                     theme->a_unfocused_unpressed_desk;
+#endif
                 break;
             case 'S':
                 a = focus ?
+#ifdef HAVE_OPENBOX_3_5_2
+                    theme->btn_shade->a_focused_unpressed :
+                    theme->btn_shade->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_shade :
                     theme->a_unfocused_unpressed_shade;
+#endif
                 break;
             case 'I':
                 a = focus ?
+#ifdef HAVE_OPENBOX_3_5_2
+                    theme->btn_iconify->a_focused_unpressed :
+                    theme->btn_iconify->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_iconify :
                     theme->a_unfocused_unpressed_iconify;
+#endif
                 break;
             case 'M':
                 a = focus ?
+#ifdef HAVE_OPENBOX_3_5_2
+                    theme->btn_max->a_focused_unpressed :
+                    theme->btn_max->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_max :
                     theme->a_unfocused_unpressed_max;
+#endif
                 break;
             case 'C':
                 a = focus ?
+#ifdef HAVE_OPENBOX_3_5_2
+                    theme->btn_close->a_focused_unpressed :
+                    theme->btn_close->a_unfocused_unpressed;
+#else
                     theme->a_focused_unpressed_close :
                     theme->a_unfocused_unpressed_close;
+#endif
                 break;
             default:
                 continue;
@@ -779,7 +809,8 @@ GdkPixbuf *preview_theme(const gchar *name, const gchar *titlelayout,
                          RrFont *inactive_window_font,
                          RrFont *menu_title_font,
                          RrFont *menu_item_font,
-                         RrFont *osd_font)
+                         RrFont *osd_active_font,
+                         RrFont *osd_inactive_font)
 {
 
     GdkPixbuf *preview;
@@ -793,7 +824,8 @@ GdkPixbuf *preview_theme(const gchar *name, const gchar *titlelayout,
 
     RrTheme *theme = RrThemeNew(rrinst, name, FALSE,
                                 active_window_font, inactive_window_font,
-                                menu_title_font, menu_item_font, osd_font);
+                                menu_title_font, menu_item_font,
+                                osd_active_font, osd_inactive_font);
     if (!theme)
         return NULL;
 
